{% extends 'board_base.html' %}
{% load i18n %}
{% load forum_conversation_tags %}

{{% block sub_title %}{% trans "Unsubscribe from topic" %}{% endblock sub_title %}

{% block content %}
  <div class="row">
    <div class="col-xs-12">
    <div class="panel panel-default post-delete">
      <div class="panel-heading">
        <h3 class="panel-title">{% trans "Unsubscribe from topic" %}</h3>
      </div>
      <div class="panel-body">
        <div class="warning-message">{% trans "Would you like to unsubscribe from this topic?" %}</div>
        <form action="" method="post">{% csrf_token %}
          <input type="hidden" name="post" value="yes" />
          <input type="submit" value="{% trans "Yes" %}" class="btn btn-warning" />
          <a href="{% url 'forum_conversation:topic' topic.forum.slug topic.forum.pk topic.slug topic.pk %}" class="btn">{% trans "No" %}</a>
        </form>
      </div>
    </div>
    </div>
  </div>
{% endblock content %}
